/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.marshalling.cloner;

/**
 * An object cloner factory.
 */
public interface ObjectClonerFactory {

    /**
     * Create a new cloner with the given configuration.
     *
     * @param configuration the configuration to use
     * @return the new cloner
     */
    ObjectCloner createCloner(ClonerConfiguration configuration);

    /**
     * An object cloner factory which produces identity object cloners.
     *
     * @see ObjectCloner#IDENTITY
     */
    ObjectClonerFactory IDENTITY = new ObjectClonerFactory() {
        public ObjectCloner createCloner(final ClonerConfiguration configuration) {
            return ObjectCloner.IDENTITY;
        }
    };
}
